@@ -7,6 +7,8 @@ has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
 has 'key'    => ( is => 'ro', isa => 'Str',        required => 1 );
 has 'method' => ( is => 'ro', isa => 'HTTPMethod', required => 1 );
 
+__PACKAGE__->meta->make_immutable;
+
 sub http_request {
     my $self = shift;
 
@@ -17,6 +19,16 @@ sub http_request {
     )->http_request;
 }
 
+sub query_string_authentication_uri {
+    my ( $self, $expires ) = @_;
+
+    return Net::Amazon::S3::HTTPRequest->new(
+        s3     => $self->s3,
+        method => $self->method,
+        path   => $self->_uri( $self->key ),
+    )->query_string_authentication_uri($expires);
+}
+
 1;
 
 __END__
@@ -44,3 +56,7 @@ This module gets an object.
 
 This method returns a HTTP::Request object.
 
+=head2 query_string_authentication_uri
+
+This method returns query string authentication URI.
+
